function A = A1(Ts,Td,Dc,mu,T0,T0i)
% Returns critical area of initiation zone (IZ) in m2
% leading to runaway rupture using A1 estimate by Galis et al. (GJI 2015).
%
% IZ is overstressed asperity, i.e., the initial traction inside IZ is expected
% to be higher than static traction. 
% Function displays a warning and returns -1 if it is not so.
%
% Ts - static traction/stress [MPa]
% Td - dynamic traction/stress [MPa]
% Dc - characteristic slip-weakeing distance [m]
% mu - shear modulus [GPa]
% T0 - initiatl traction outside the initiation zone [MPa]
% T0i - initiation traction inside the initiation zone [MPa]
%
% This estimate is valid for S > ~0.75 and Poisson's ratio ~0.25.
% For lower S, estimate by Uenishi 2009 is sufficient for a runaway rupture. 
% Also note that A2 estimate is more accurate.
% See Galis et al., 2015 for more details.
%
% For Poisson's ratio ~0.25 and
%        S < ~0.75 this estimate leads to a RUNAWAY rupture
%        S > ~0.75 this estimate leads to s STOPPING ruptures.
%                 For runaway ruptures use A1 or A2 by Galis et al., 2015
% 
% Strength parameter S = (Ts - T0) / (T0 - Td), where 
%   Ts - static traction,
%   Td - dynamic traction,
%   T0 - initial traction outside initiation zone
%
% for full details please see Appendix A of  
% Galis, M., Pelties, C., Kristek, J., Moczo, P., Ampuero,  J.-P., Mai, P. M., 2015.  
%    On the initiation of sustained slip-weakening ruptures by localized stresses 
%    Geophys. J. Int., 200, 888-907, doi: 10.1093/gji/ggu436
%
%--------------------------------------------------------------------------
% Written by 
%      Martin Galis, May 2015                        martin.galis@kaust.edu.sa
%--------------------------------------------------------------------------

    if T0i <= Ts
      A = -1;
      disp('T0i is lower than Ts, please check input parameters.');
      return
    end

    A =   (3*pi)^3 * mu^2 * Dc^2 *       (Ts - Td)^2        ...
    / (  2^11*                    (T0i-T0) * (T0 - Td)^3  ); 

end