function A = AUenishi2009( Ts, Td, Dc, mu, ni )
% Returns critical area of initiation zone (IZ) in m2 using estimate by Uenishi (2009).
%
% IZ is overstressed asperity, i.e., the initial traction inside IZ 
% is expected to be higher than static traction. 
%
% Ts - static traction/stress [Pa]
% Td - dynamic traction/stress [Pa]
% Dc - characteristic slip-weakeing distance [m]
% mu - shear modulus [Pa]
% ni - Poisson's ratio
%
% This estimate is valid for low overstress (difference between initial traction
% inside IZ and static traction. For higher overstresses, even smaller area may lead
% to runaway rupture, as discussed by Galis et al., 2015.
%
% For Poisson's ratio ~0.25 and
%        S < ~0.75 this estimate leads to a RUNAWAY rupture
%        S > ~0.75 this estimate leads to s STOPPING ruptures.
%                 For runaway ruptures use A1 or A2 by Galis et al., 2015
%     
% References:
% Galis, M., Pelties, C., Kristek, J., Moczo, P., Ampuero,  J.-P., Mai, P. M., 2015.  
%    On the initiation of sustained slip-weakening ruptures by localized stresses 
%    Geophys. J. Int., 200, 888-907, doi: 10.1093/gji/ggu436
%
% Uenishi, K., 2009. 
%    On the mechanical destabilization of a three-dimensional 
%    displacement-softening plane of weakness, 
%    in Proceedings of the 38th Symposium on Rock Mechanics, Tokyo, Japan, 
%    8-9 January 2009 pp. 332?337, Committee on Rock Mechanics, The Japan 
%    Society of Civil Engineers, Tokyo, Japan.
%
%--------------------------------------------------------------------------
% Written by 
%      Martin Galis, May 2015                        martin.galis@kaust.edu.sa
%--------------------------------------------------------------------------

    m = ni*(2-ni);
    [K,E]=ellipke(m);

    C = ( E +(1-ni)*K )/(2-ni);
    W = (Ts - Td)/Dc;

    b = 0.624*C*mu/W;
    a = b / (1-ni);

    A = pi*a*b;
    
end