function A = CritArr(Ts,Td,Dc,mu,ni,T0,T0i)
% Returns critical area of initiation zone (IZ) in m2 leading to runaway rupture, 
% defined as max(A2,AU2009), 
% where A2 is estimate by Galis et al. 2015
% and AU2009 is estimate b Uenishi 2009. 
%
% IZ is overstressed asperity, i.e., the initial traction inside IZ is expected
% to be higher than static traction. 
% Function displays a warning and returns -1 if it is not so.
%
% See Galis et al., 2015 for more details.
% 
% Ts - static traction/stress [Pa]
% Td - dynamic traction/stress [Pa]
% Dc - characteristic slip-weakeing distance [m]
% mu - shear modulus [Pa]
% mu - Poisson ratio
% T0 - initiatl traction outside the initiation zone [Pa]
% T0i - initiation traction inside the initiation zone [Pa]
%
% for full details please see Appendix A of  
% Galis, M., Pelties, C., Kristek, J., Moczo, P., Ampuero,  J.-P., Mai, P. M., 2015.  
%    On the initiation of sustained slip-weakening ruptures by localized stresses 
%    Geophys. J. Int., 200, 888-907, doi: 10.1093/gji/ggu436
%
% Uenishi, K., 2009. 
%    On the mechanical destabilization of a three-dimensional 
%    displacement-softening plane of weakness, 
%    in Proceedings of the 38th Symposium on Rock Mechanics, Tokyo, Japan, 
%    8-9 January 2009 pp. 332?337, Committee on Rock Mechanics, The Japan 
%    Society of Civil Engineers, Tokyo, Japan.
%
%--------------------------------------------------------------------------
% Written by 
%      Martin Galis, May 2015                        martin.galis@kaust.edu.sa
%--------------------------------------------------------------------------

A_2     = A2          (Ts,Td,Dc,mu,   T0,T0i);
A_U2009 = AUenishi2009(Ts,Td,Dc,mu,ni);
    
if A_2< 0
     A = -1;
else
     A = max(A_2,A_U2009);
end
end